@@ -110,7 +110,7 @@ class Utils(object):
 			ecr_username, ecr_password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
 			registry = token['authorizationData'][0]['proxyEndpoint']
 		except Exception as e:
-			raise DockerError('Login to docker failed while getting ECR authorization token: ' + str(e))
+			raise DockerError('Login to docker failed while getting ECR authorization token: ' + str(e), None)
 
 		command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
 		if sys.version_info < (3, 0):
@@ -123,7 +123,7 @@ class Utils(object):
 		if stdout is not None and stdout.decode('utf-8').find('Login Succeeded') >= 0:
 			print('Login to docker succeeded.')
 		else:
-			raise DockerError('Login to docker failed: ' + stdout.decode('utf-8'))
+			raise DockerError('Login to docker failed: ' + stdout.decode('utf-8'), None)
 
 		client = docker.from_env()
 		cls.last_time_docker_login = cls.get_timestamp()
@@ -160,7 +160,7 @@ class Utils(object):
 			try:
 				docker_client.images.get(image)
 			except Exception as de:
-				raise DockerError('Failed to pull image: ' + str(e))
+				raise DockerError('Failed to pull image: ' + str(e), None)
 
 		
 	@classmethod
